'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.LogService = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _winston = require('winston');

var _winston2 = _interopRequireDefault(_winston);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var TERM_COLORS = {
    error: "red",
    warn: "yellow",
    info: "blue",
    verbose: "white",
    silly: "grey"
};

/**
 * Configuration options for the log service
 */

var LogConfig = function LogConfig() {
    _classCallCheck(this, LogConfig);

    this.file = "logs/matrix.log";
    this.console = true;
    this.consoleLevel = "info";
    this.fileLevel = "verbose";
    this.rotate = {
        size: 52428800, // bytes, default is 50mb
        count: 5
    };
};

var currentConfig = new LogConfig();
var transports = [];
var logger = null;

/**
 * Exposes an easy replacement for console.log
 */

var LogService = exports.LogService = function () {
    function LogService() {
        _classCallCheck(this, LogService);
    }

    _createClass(LogService, null, [{
        key: 'configure',


        /**
         * Configures the log service
         * @param {LogConfig|{file:string, console:boolean, consoleLevel: string, fileLevel: string, rotate:{size:number, count:number}}} logConfig The configuration to use
         */
        value: function configure(logConfig) {
            if (!logConfig) logConfig = new LogConfig();
            currentConfig = logConfig;

            var dir = _path2.default.join(logConfig.file, '..');
            try {
                _fs2.default.mkdirSync(dir);
            } catch (ex) {
                // Ignore errors
            }

            transports.push(new _winston2.default.transports.File({
                json: false,
                name: "file",
                filename: logConfig.file,
                timestamp: LogService._now,
                formatter: LogService._winstonFormatter,
                level: logConfig.fileLevel,
                maxsize: logConfig.rotate.size,
                maxFiles: logConfig.rotate.count,
                zippedArchive: false
            }));

            if (logConfig.console) {
                transports.push(new _winston2.default.transports.Console({
                    json: false,
                    name: "console",
                    timestamp: LogService._now,
                    formatter: LogService._winstonColorFormatter,
                    level: logConfig.consoleLevel
                }));
            }

            logger = new _winston2.default.Logger({
                transports: transports,
                levels: {
                    error: 0,
                    warn: 1,
                    info: 2,
                    verbose: 3,
                    silly: 4
                }
            });
        }
    }, {
        key: '_winstonColorFormatter',
        value: function _winstonColorFormatter(options) {
            options.level = _chalk2.default[TERM_COLORS[options.level]](options.level);
            return LogService._winstonFormatter(options);
        }
    }, {
        key: '_winstonFormatter',
        value: function _winstonFormatter(options) {
            return options.timestamp() + ' ' + options.level + ' ' + (options.message ? options.message : '') + (options.meta && Object.keys(options.meta).length ? '\n\t' + JSON.stringify(options.meta) : '');
        }
    }, {
        key: '_now',
        value: function _now() {
            return (0, _moment2.default)().format('MMM-D-YYYY HH:mm:ss.SSS Z');
        }
    }, {
        key: '_doLog',
        value: function _doLog(level, module, messageOrObject) {
            if (!logger) {
                LogService.configure(new LogConfig());
            }

            if ((typeof messageOrObject === 'undefined' ? 'undefined' : _typeof(messageOrObject)) === 'object' && !(messageOrObject instanceof Error)) messageOrObject = JSON.stringify(messageOrObject);

            if (messageOrObject instanceof Error) {
                var err = messageOrObject;
                messageOrObject = err.message + "\n" + err.stack;
            }

            var message = "[" + module + "] " + messageOrObject;
            logger.log(level, message);
        }

        /**
         * Logs a message at the level INFO
         * @param {string} module The module the message is being logged in
         * @param {*} message A string or object to log. Errors will be expanded.
         */

    }, {
        key: 'info',
        value: function info(module, message) {
            LogService._doLog('info', module, message);
        }

        /**
         * Logs a message at the level WARN
         * @param {string} module The module the message is being logged in
         * @param {*} message A string or object to log. Errors will be expanded.
         */

    }, {
        key: 'warn',
        value: function warn(module, message) {
            LogService._doLog('warn', module, message);
        }

        /**
         * Logs a message at the level ERROR
         * @param {string} module The module the message is being logged in
         * @param {*} message A string or object to log. Errors will be expanded.
         */

    }, {
        key: 'error',
        value: function error(module, message) {
            LogService._doLog('error', module, message);
        }

        /**
         * Logs a message at the level VERBOSE
         * @param {string} module The module the message is being logged in
         * @param {*} message A string or object to log. Errors will be expanded.
         */

    }, {
        key: 'verbose',
        value: function verbose(module, message) {
            LogService._doLog('verbose', module, message);
        }

        /**
         * Logs a message at the level SILLY
         * @param {string} module The module the message is being logged in
         * @param {*} message A string or object to log. Errors will be expanded.
         */

    }, {
        key: 'silly',
        value: function silly(module, message) {
            LogService._doLog('silly', module, message);
        }
    }]);

    return LogService;
}();